@@ -22,18 +22,17 @@
 #include <AkonadiCore/attribute.h>
 #include "noteshared_export.h"
 
-namespace NoteShared
-{
+namespace NoteShared {
 class NOTESHARED_EXPORT ShowFolderNotesAttribute : public Akonadi::Attribute
 {
 public:
     ShowFolderNotesAttribute();
     ~ShowFolderNotesAttribute();
 
-    ShowFolderNotesAttribute *clone() const Q_DECL_OVERRIDE;
-    QByteArray type() const Q_DECL_OVERRIDE;
-    QByteArray serialized() const Q_DECL_OVERRIDE;
-    void deserialize(const QByteArray &data) Q_DECL_OVERRIDE;
+    ShowFolderNotesAttribute *clone() const override;
+    QByteArray type() const override;
+    QByteArray serialized() const override;
+    void deserialize(const QByteArray &data) override;
 };
 }
 
