@@ -20,16 +20,15 @@
 #define NOTEACTIONCONFIG_H
 #include "noteshared_export.h"
 #include <KCModule>
-namespace NoteShared
-{
+namespace NoteShared {
 class NOTESHARED_EXPORT NoteActionConfig : public KCModule
 {
     Q_OBJECT
 public:
     NoteActionConfig(QWidget *parent);
     /** Reimplemented from KCModule. */
-    void load() Q_DECL_OVERRIDE;
-    void save() Q_DECL_OVERRIDE;
+    void load() override;
+    void save() override;
 
 private Q_SLOTS:
     void slotHelpLinkClicked(const QString &);
