@@ -23,8 +23,7 @@
 #include <QObject>
 
 class KJob;
-namespace NoteShared
-{
+namespace NoteShared {
 class NOTESHARED_EXPORT LocalResourceCreator : public QObject
 {
     Q_OBJECT
