@@ -32,9 +32,12 @@ class KNotesUniqueAppHandler : public KontactInterface::UniqueAppHandler
     Q_OBJECT
 public:
     explicit KNotesUniqueAppHandler(KontactInterface::Plugin *plugin)
-        : KontactInterface::UniqueAppHandler(plugin) {}
-    void loadCommandLineOptions(QCommandLineParser *parser) Q_DECL_OVERRIDE;
-    int activate(const QStringList &args, const QString &workingDir) Q_DECL_OVERRIDE;
+        : KontactInterface::UniqueAppHandler(plugin)
+    {
+    }
+
+    void loadCommandLineOptions(QCommandLineParser *parser) override;
+    int activate(const QStringList &args, const QString &workingDir) override;
 };
 
 class KNotesPlugin : public KontactInterface::Plugin
@@ -44,30 +47,29 @@ public:
     KNotesPlugin(KontactInterface::Core *core, const QVariantList &);
     ~KNotesPlugin();
 
-    KontactInterface::Summary *createSummaryWidget(QWidget *parentWidget) Q_DECL_OVERRIDE;
+    KontactInterface::Summary *createSummaryWidget(QWidget *parentWidget) override;
 
-    bool isRunningStandalone() const Q_DECL_OVERRIDE;
+    bool isRunningStandalone() const override;
 
-    int weight() const Q_DECL_OVERRIDE
+    int weight() const override
     {
         return 600;
     }
 
-    const KAboutData aboutData() Q_DECL_OVERRIDE;
+    const KAboutData aboutData() override;
 
-    bool canDecodeMimeData(const QMimeData *data) const Q_DECL_OVERRIDE;
-    void processDropEvent(QDropEvent *) Q_DECL_OVERRIDE;
-    void shortcutChanged() Q_DECL_OVERRIDE;
+    bool canDecodeMimeData(const QMimeData *data) const override;
+    void processDropEvent(QDropEvent *) override;
+    void shortcutChanged() override;
 
 protected:
-    KParts::ReadOnlyPart *createPart() Q_DECL_OVERRIDE;
+    KParts::ReadOnlyPart *createPart() override;
 
 private Q_SLOTS:
     void slotNewNote();
 
 private:
     KontactInterface::UniqueAppWatcher *mUniqueAppWatcher;
-
 };
 
 #endif
